==> zio-aws-lambda_2.12-5.17.127.1-sources.jar: zio/aws/lambda/model/GetLayerVersionPolicyResponse.scala <==
package zio.aws.lambda.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetLayerVersionPolicyResponse(
    policy: Option[String] = None,
    revisionId: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse = {
    import GetLayerVersionPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
      .builder()
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .optionallyWith(revisionId.map(value => value: java.lang.String))(
        _.revisionId
      )
      .build()
  }
  def asReadOnly: zio.aws.lambda.model.GetLayerVersionPolicyResponse.ReadOnly =
    zio.aws.lambda.model.GetLayerVersionPolicyResponse.wrap(buildAwsValue())
}
object GetLayerVersionPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.GetLayerVersionPolicyResponse =
      zio.aws.lambda.model.GetLayerVersionPolicyResponse(
        policy.map(value => value),
        revisionId.map(value => value)
      )
    def policy: Option[String]
    def revisionId: Option[String]
    def getPolicy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("policy", policy)
    def getRevisionId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("revisionId", revisionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
  ) extends zio.aws.lambda.model.GetLayerVersionPolicyResponse.ReadOnly {
    override val policy: Option[String] =
      scala.Option(impl.policy()).map(value => value: String)
    override val revisionId: Option[String] =
      scala.Option(impl.revisionId()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
  ): zio.aws.lambda.model.GetLayerVersionPolicyResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-lambda_2.12-5.17.295.10-sources.jar: zio/aws/lambda/model/GetLayerVersionPolicyResponse.scala <==
package zio.aws.lambda.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetLayerVersionPolicyResponse(
    policy: Optional[String] = Optional.Absent,
    revisionId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse = {
    import GetLayerVersionPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
      .builder()
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .optionallyWith(revisionId.map(value => value: java.lang.String))(
        _.revisionId
      )
      .build()
  }
  def asReadOnly: zio.aws.lambda.model.GetLayerVersionPolicyResponse.ReadOnly =
    zio.aws.lambda.model.GetLayerVersionPolicyResponse.wrap(buildAwsValue())
}
object GetLayerVersionPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.GetLayerVersionPolicyResponse =
      zio.aws.lambda.model.GetLayerVersionPolicyResponse(
        policy.map(value => value),
        revisionId.map(value => value)
      )
    def policy: Optional[String]
    def revisionId: Optional[String]
    def getPolicy: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("policy", policy)
    def getRevisionId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("revisionId", revisionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
  ) extends zio.aws.lambda.model.GetLayerVersionPolicyResponse.ReadOnly {
    override val policy: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.policy())
      .map(value => value: String)
    override val revisionId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.revisionId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.GetLayerVersionPolicyResponse
  ): zio.aws.lambda.model.GetLayerVersionPolicyResponse.ReadOnly = new Wrapper(
    impl
  )
}
